@@ -36,7 +36,7 @@
 
 
 
-#define VERSION "7.486"
+#define VERSION "7.526"
 #define SHOWVERSION reporterr( "%s (%s) Version " VERSION "\nalg=%c, model=%s, amax=%3.1f\n%d thread(s)\n\n", progName( argv[0] ), (dorp=='d')?"nuc":((nblosum==-2)?"text":"aa"), alg, modelname, specificityconsideration, nthread )
 
 #define FFT_THRESHOLD  80
@@ -48,6 +48,7 @@
 #define M  500000       /* njob no saidaiti */
 #define N 5000000       /* nlen no saidaiti */
 #define MAXSEG 100000
+#define MAXSEG_GIVENANCHORS 10000000
 #define B     256
 #define C     60       /*  1 gyou no mojisuu */
 #define D      6
@@ -331,6 +332,13 @@ typedef struct _extanch
 	int score;
 } ExtAnch;
 
+typedef struct _gappos
+{
+	int pos;
+	int len;
+} GapPos;
+
+
 #include "fft.h"
 #include "dp.h"
 #include "functions.h"
@@ -376,6 +384,13 @@ extern double sueff_global;
 extern double lenfaca, lenfacb, lenfacc, lenfacd;
 extern int maxl, tsize;
 
+extern char codonpos;
+extern char codonscore;
+
+extern char distout;
+
+extern int terminalmargin;
+
 
 /* for --large  */
 extern int compacttree;
@@ -385,3 +400,4 @@ extern int specifictarget;
 extern int nadd;
 extern int usenaivescoreinsteadofalignmentscore;
 #define MYBUFSIZE 1000 * 1000 * 100 // 100MB
+extern int LineLengthInFASTA;
